==> aws-cdk-lib-2.0.0-rc.14-sources.jar: software/amazon/awscdk/CfnRuleAssertion.java <==
package software.amazon.awscdk;

/**
 * (experimental) A rule assertion.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T10:23:53.797Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.CfnRuleAssertion")
@software.amazon.jsii.Jsii.Proxy(CfnRuleAssertion.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface CfnRuleAssertion extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The assertion.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.ICfnConditionExpression getAssertValue();

    /**
     * (experimental) The assertion description.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getAssertDescription();

    /**
     * @return a {@link Builder} of {@link CfnRuleAssertion}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnRuleAssertion}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<CfnRuleAssertion> {
        private software.amazon.awscdk.ICfnConditionExpression assertValue;
        private java.lang.String assertDescription;

        /**
         * Sets the value of {@link CfnRuleAssertion#getAssertValue}
         * @param assertValue The assertion. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder assertValue(software.amazon.awscdk.ICfnConditionExpression assertValue) {
            this.assertValue = assertValue;
            return this;
        }

        /**
         * Sets the value of {@link CfnRuleAssertion#getAssertDescription}
         * @param assertDescription The assertion description. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder assertDescription(java.lang.String assertDescription) {
            this.assertDescription = assertDescription;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnRuleAssertion}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public CfnRuleAssertion build() {
            return new Jsii$Proxy(assertValue, assertDescription);
        }
    }

    /**
     * An implementation for {@link CfnRuleAssertion}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnRuleAssertion {
        private final software.amazon.awscdk.ICfnConditionExpression assertValue;
        private final java.lang.String assertDescription;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.assertValue = software.amazon.jsii.Kernel.get(this, "assert", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.ICfnConditionExpression.class));
            this.assertDescription = software.amazon.jsii.Kernel.get(this, "assertDescription", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.ICfnConditionExpression assertValue, final java.lang.String assertDescription) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.assertValue = java.util.Objects.requireNonNull(assertValue, "assertValue is required");
            this.assertDescription = java.util.Objects.requireNonNull(assertDescription, "assertDescription is required");
        }

        @Override
        public final software.amazon.awscdk.ICfnConditionExpression getAssertValue() {
            return this.assertValue;
        }

        @Override
        public final java.lang.String getAssertDescription() {
            return this.assertDescription;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("assert", om.valueToTree(this.getAssertValue()));
            data.set("assertDescription", om.valueToTree(this.getAssertDescription()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.CfnRuleAssertion"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnRuleAssertion.Jsii$Proxy that = (CfnRuleAssertion.Jsii$Proxy) o;

            if (!assertValue.equals(that.assertValue)) return false;
            return this.assertDescription.equals(that.assertDescription);
        }

        @Override
        public final int hashCode() {
            int result = this.assertValue.hashCode();
            result = 31 * result + (this.assertDescription.hashCode());
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/CfnRuleAssertion.java <==
package software.amazon.awscdk;

/**
 * A rule assertion.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.*;
 * ICfnConditionExpression cfnConditionExpression;
 * CfnRuleAssertion cfnRuleAssertion = CfnRuleAssertion.builder()
 *         .assert(cfnConditionExpression)
 *         .assertDescription("assertDescription")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:06.808Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.CfnRuleAssertion")
@software.amazon.jsii.Jsii.Proxy(CfnRuleAssertion.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnRuleAssertion extends software.amazon.jsii.JsiiSerializable {

    /**
     * The assertion.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.ICfnConditionExpression getAssertValue();

    /**
     * The assertion description.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAssertDescription();

    /**
     * @return a {@link Builder} of {@link CfnRuleAssertion}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnRuleAssertion}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnRuleAssertion> {
        software.amazon.awscdk.ICfnConditionExpression assertValue;
        java.lang.String assertDescription;

        /**
         * Sets the value of {@link CfnRuleAssertion#getAssertValue}
         * @param assertValue The assertion. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder assertValue(software.amazon.awscdk.ICfnConditionExpression assertValue) {
            this.assertValue = assertValue;
            return this;
        }

        /**
         * Sets the value of {@link CfnRuleAssertion#getAssertDescription}
         * @param assertDescription The assertion description. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder assertDescription(java.lang.String assertDescription) {
            this.assertDescription = assertDescription;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnRuleAssertion}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnRuleAssertion build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnRuleAssertion}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnRuleAssertion {
        private final software.amazon.awscdk.ICfnConditionExpression assertValue;
        private final java.lang.String assertDescription;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.assertValue = software.amazon.jsii.Kernel.get(this, "assert", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.ICfnConditionExpression.class));
            this.assertDescription = software.amazon.jsii.Kernel.get(this, "assertDescription", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.assertValue = java.util.Objects.requireNonNull(builder.assertValue, "assertValue is required");
            this.assertDescription = java.util.Objects.requireNonNull(builder.assertDescription, "assertDescription is required");
        }

        @Override
        public final software.amazon.awscdk.ICfnConditionExpression getAssertValue() {
            return this.assertValue;
        }

        @Override
        public final java.lang.String getAssertDescription() {
            return this.assertDescription;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("assert", om.valueToTree(this.getAssertValue()));
            data.set("assertDescription", om.valueToTree(this.getAssertDescription()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.CfnRuleAssertion"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnRuleAssertion.Jsii$Proxy that = (CfnRuleAssertion.Jsii$Proxy) o;

            if (!assertValue.equals(that.assertValue)) return false;
            return this.assertDescription.equals(that.assertDescription);
        }

        @Override
        public final int hashCode() {
            int result = this.assertValue.hashCode();
            result = 31 * result + (this.assertDescription.hashCode());
            return result;
        }
    }
}
